# Generated by Django 4.1.10 on 2023-08-04 14:11

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_feedback_govuk", "0003_restructure_feedback"),
    ]

    operations = [
        migrations.AlterField(
            model_name="basefeedback",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]



# Generated by Django 3.2.18 on 2023-05-12 05:15

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("django_feedback_govuk", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="feedback",
            name="submitter",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]
